<?php
namespace WglAddons\Controls;

use Elementor\Plugin;
use Elementor\Controls_Manager;
use Elementor\Base_Data_Control;

if ( ! defined( 'ABSPATH' ) ) { exit; }

/**
* Wgl Elementor Custom Icon Control
*
*
* @class        Wgl_Icon
* @version      1.0
* @category Class
* @author       WebGeniusLab
*/

class Wgl_Icon extends Base_Data_Control{

    /**
     * Get radio image control type.
     *
     * Retrieve the control type, in this case `radio-image`.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Control type.
     */
    public function get_type() {
        return 'wgl-icon';
    }

    public function enqueue() {
        // Scripts
        wp_enqueue_script( 'wgl-elementor-extensions', WGL_ELEMENTOR_ADDONS_URL . 'assets/js/wgl_elementor_extenstions.js');

        // Style
        wp_enqueue_style( 'wgl-elementor-extensions', WGL_ELEMENTOR_ADDONS_URL . 'assets/css/wgl_elementor_extenstions.css');
    }

    public static function get_flaticons( ) {
        return array(
            'flaticon-idea' => 'idea',
            'flaticon-3d-cube' => '3d-cube',
            'flaticon-ruler' => 'ruler',
            'flaticon-pantone' => 'pantone',
            'flaticon-tools' => 'tools',
            'flaticon-conversation' => 'conversation',
            'flaticon-woman' => 'woman',
            'flaticon-update' => 'update',
            'flaticon-info' => 'info',
            'flaticon-check' => 'check',
            'flaticon-cross' => 'cross',
            'flaticon-layers' => 'layers',
            'flaticon-megaphone' => 'megaphone',
            'flaticon-vector' => 'vector',
            'flaticon-filter' => 'filter',
            'flaticon-menu' => 'menu',
            'flaticon-compass' => 'compass',
            'flaticon-sketch' => 'sketch',
            'flaticon-paint-bucket' => 'paint-bucket',
            'flaticon-rgb' => 'rgb',
            'flaticon-messages' => 'messages',
            'flaticon-briefcase' => 'briefcase',
            'flaticon-news' => 'news',
            'flaticon-video-player' => 'video-player',
            'flaticon-statistics' => 'statistics',
            'flaticon-live-news' => 'live-news',
            'flaticon-pencil' => 'pencil',
            'flaticon-clock' => 'clock',
            'flaticon-paint-palette' => 'paint-palette',
            'flaticon-bookmark' => 'bookmark',
            'flaticon-clock-1' => 'clock-1',
            'flaticon-placeholder' => 'placeholder',
            'flaticon-placeholder-1' => 'placeholder-1',
            'flaticon-internet' => 'internet',
            'flaticon-search' => 'search',
            'flaticon-shopping-bag' => 'shopping-bag',
            'flaticon-phone-call' => 'phone-call',
            'flaticon-magnifying-glass' => 'magnifying-glass',
            'flaticon-email' => 'email',
            'flaticon-user' => 'user',
            'flaticon-heart' => 'heart',
            'flaticon-envelope' => 'envelope',
            'flaticon-comment-white-oval-bubble' => 'comment-white-oval-bubble',
            'flaticon-heart-black-shape-for-valentines' => 'heart-black-shape-for-valentines',
            'flaticon-play-arrow' => 'play-arrow',
            'flaticon-house-outline' => 'house-outline',
            'flaticon-clock-2' => 'clock-2',
            'flaticon-bookmark-1' => 'bookmark-1',
            'flaticon-music-player-play' => 'music-player-play',
            'flaticon-library-bookmark' => 'library-bookmark',
            'flaticon-big-and-small-dots' => 'big-and-small-dots',
            'flaticon-magnifying-glass-1' => 'magnifying-glass-1',
            'flaticon-next' => 'next',
            'flaticon-back' => 'back',
            'flaticon-close' => 'close',
            'flaticon-info-1' => 'info-1',
            'flaticon-information' => 'information',
            'flaticon-close-cross-circular-interface-button' => 'close-cross-circular-interface-button',
            'flaticon-share' => 'share',
            'flaticon-heart-1' => 'heart-1',
            'flaticon-heart-2' => 'heart-2',
            'flaticon-unlink' => 'unlink',
        );
    }

    /**
     * Get radio image control default settings.
     *
     *
     * @since 1.0.0
     * @access protected
     *
     * @return array Control default settings.
     */
    protected function get_default_settings() {
        return [
            'label_block' => true,
            'options' => self::get_flaticons(),
            'include' => '',
            'exclude' => '',
            'select2options' => [],
        ];
    }

    /**
     * Render radio image control output in the editor.
     *
     * Used to generate the control HTML in the editor using Underscore JS
     * template. The variables for the class are available using `data` JS
     * object.
     *
     * @since 1.0.0
     * @access public
     */
    public function content_template() {

        $control_uid = $this->get_control_uid();
        ?>
        <div class="elementor-control-field">
            <# if ( data.label ) {#>
                <label for="<?php echo $control_uid; ?>" class="elementor-control-title">{{{ data.label }}}</label>
            <# } #>
            <div class="elementor-control-input-wrapper">
                <select id="<?php echo $control_uid; ?>" class="elementor-control-icon elementor-select2" type="select2"  data-setting="{{ data.name }}" data-placeholder="<?php echo __( 'Select Icon', 'stoni-core' ); ?>">
                    <# _.each( data.options, function( option_title, option_value ) {
                        var value = data.controlValue;
                        if ( typeof value == 'string' ) {
                            var selected = ( option_value === value ) ? 'selected' : '';
                        } else if ( null !== value ) {
                            var value = _.values( value );
                            var selected = ( -1 !== value.indexOf( option_value ) ) ? 'selected' : '';
                        }
                        #>
                    <option {{ selected }} value="{{ option_value }}">{{{ option_title }}}</option>
                    <# } ); #>
                </select>
            </div>
        </div>
        <# if ( data.description ) { #>
            <div class="elementor-control-field-description">{{{ data.description }}}</div>
        <# } #>
        <?php
    }
}

?>