<?php
namespace WglAddons\Includes;

defined('ABSPATH') || exit;

use Elementor\{
    Controls_Manager,
    Control_Media,
    Utils,
    Group_Control_Image_Size
};

if (!class_exists('Wgl_Icons')) {
    /**
    * Wgl Elementor Icons Settins
    *
    *
    * @package stoni-core\includes\elementor
    * @author WebGeniusLab <webgeniuslab@gmail.com>
    * @since 1.0.0
    */
    class Wgl_Icons
    {
        private static $instance;

        public static function get_instance()
        {
            if (is_null(self::$instance)) {
                self::$instance = new self();
            }

            return self::$instance;
        }

        public function build($self, $atts)
        {
            return (new Wgl_Icon_Builder())->build($self, $atts);
        }

        public static function init($self, $array = [])
        {
            if (!$self) {
                return;
            }

            $array['label'] = $array['label'] ?? '';

            $self->start_controls_section(
	            'add_icon_image_section',
	            ['label' => sprintf(esc_html__('%sIcon/Image', 'stoni-core'), esc_html($array['label']))]
	        );

            $self->add_control(
                'icon_type',
                [
                    'label' => esc_html__('Add Icon/Image', 'stoni-core'),
                    'type' => Controls_Manager::CHOOSE,
                    'label_block' => false,
                    'options' => [
                        '' => [
                            'title' => esc_html__('None', 'stoni-core'),
                            'icon' => 'fa fa-ban',
                        ],
                        'font' => [
                            'title' => esc_html__('Icon', 'stoni-core'),
                            'icon' => 'fa fa-smile-o',
                        ],
                        'image' => [
                            'title' => esc_html__('Image', 'stoni-core'),
                            'icon' => 'fa fa-picture-o',
                        ]
                    ],
                    'default' => '',
                ]
            );

            $self->add_control(
                'icon_pack',
                [
                    'label' => esc_html__('Icon Pack', 'stoni-core'),
                    'type' => Controls_Manager::SELECT,
                    'condition' => ['icon_type' => 'font'],
                    'options' => [
                        'fontawesome' => esc_html__('Fontawesome', 'stoni-core'),
                        'flaticon' => esc_html__('Flaticon', 'stoni-core'),
                    ],
                    'default' => 'fontawesome',
                ]
            );

            $self->add_control(
                'icon_flaticon',
                [
                    'label' => esc_html__('Icon', 'stoni-core'),
                    'type' => 'wgl-icon',
                    'condition' => [
                        'icon_pack' => 'flaticon',
                        'icon_type' => 'font',
                    ],
                    'label_block' => true,
                    'description' => esc_html__('Select icon from Flaticon library.', 'stoni-core'),
                ]
            );

            $self->add_control(
                'icon_fontawesome',
                [
                    'label' => esc_html__('Icon', 'stoni-core'),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'condition' => [
                        'icon_pack' => 'fontawesome',
                        'icon_type' => 'font',
                    ],
                    'description' => esc_html__('Select icon from Fontawesome library.', 'stoni-core'),
                ]
            );

            $self->add_control(
                'icon_render_class',
                [
                    'label' => esc_html__('Icon Class', 'stoni-core'),
                    'type' => Controls_Manager::HIDDEN,
                    'condition' => ['icon_type' => 'font'],
                    'prefix_class' => 'elementor-widget-icon-box ',
                    'default' => 'wgl-icon-box',
                ]
            );

            $self->add_control(
                'thumbnail',
                [
                    'label' => esc_html__('Image', 'stoni-core'),
                    'type' => Controls_Manager::MEDIA,
                    'condition' => ['icon_type' => 'image'],
                    'label_block' => true,
                    'default' => ['url' => Utils::get_placeholder_image_src()],
                ]
            );

            $self->add_control(
                'image_render_class',
                [
                    'label' => esc_html__('Image Class', 'stoni-core'),
                    'type' => Controls_Manager::HIDDEN,
                    'condition' => ['icon_type' => 'image'],
                    'prefix_class' => 'elementor-widget-image-box ',
                    'default' => 'wgl-image-box',
                ]
            );

            $self->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name' => 'thumbnail',
                    'default' => 'full',
                    'separator' => 'none',
                    'condition' => ['icon_type' => 'image'],
                ]
            );

            if (!empty($array['output'])) {
                foreach ($array['output'] as $key => $value) {
                    $self->add_control(
                        $key,
                        $value
                    );
                }
            }

	        $self->end_controls_section();
        }
    }

    new Wgl_Icons();
}

if (!class_exists('Wgl_Icon_Builder')) {
    /**
     * Wgl Icon Build
     *
     *
     * @package stoni-core\includes\elementor
     * @author WebGeniusLab <webgeniuslab@gmail.com>
     * @since 1.0.0
     */
    class Wgl_Icon_Builder
    {
        private static $instance;

        public static function get_instance()
        {
            if (is_null(self::$instance)) {
                self::$instance = new self();
            }

            return self::$instance;
        }

        public function build($self, $atts)
        {
            extract($atts);

            $self->add_render_attribute('icon', 'class', ['wgl-icon', 'elementor-icon']);
            if (isset($atts['hover_animation_icon'])) {
                $self->add_render_attribute('icon', 'class', 'elementor-animation-' . $atts['hover_animation_icon']);
            }

            $wrapper_class = $wrapper_class ?? 'wgl-widget_wrapper';

            if ($icon_type) {
                if ('image' === $icon_type) {
                    $wrapper_class .= ' elementor-image-box-img';
                } elseif (!is_a($self, 'WglAddons\Widgets\Wgl_Button')) {
                    $wrapper_class .= ' elementor-icon-box-icon';
                }
            }

            $self->add_render_attribute('wrapper', 'class', $wrapper_class);

            $container_class = $container_class ?? 'wgl-widget_container';
            $self->add_render_attribute('container', 'class', $container_class);

            $icon_tag = 'span';

            if (!empty($atts['link_t']['url'])) {
                $icon_tag = 'a';
                $self->add_link_attributes('link_t', $atts['link_t']);
            }

            $icon_attributes = $self->get_render_attribute_string('icon');
            $link_attributes = $self->get_render_attribute_string('link_t');

            $wrapper = $self->get_render_attribute_string('wrapper');
            $container = $self->get_render_attribute_string('container');

            $output = '';
            if (
                $icon_type == 'font' && (!empty($icon_fontawesome) || !empty($icon_flaticon))
                || $icon_type == 'image' && !empty($thumbnail)
            ) {
                $output .= '<div ' . implode(' ', [$wrapper]) . '>';
                    $output .= '<div ' . implode(' ', [$container]) . '>';

                        if (
                            $icon_type == 'font'
                            && (!empty($icon_fontawesome) || !empty($icon_flaticon))
                        ) {
                            switch ($icon_pack) {
                                case 'fontawesome':
                                    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
                                    $icon_font = $icon_fontawesome;
                                    break;
                                case 'flaticon':
                                    wp_enqueue_style('stoni-flaticon', get_template_directory_uri() . '/fonts/flaticon/flaticon.css');
                                    $icon_font = $icon_flaticon;
                                    break;
                            }

                            $output .= '<';
                                $output .= implode(' ', [$icon_tag, $icon_attributes, $link_attributes]);
                            $output .= '>';
                                $output .= '<i class="icon ' . esc_attr($icon_font) . '"></i>';

                            $output .= '</'.$icon_tag.'>';
                        }

                        if (
                            $icon_type == 'image'
                            && !empty($thumbnail)
                            && !empty($atts['thumbnail']['url'])
                        ) {
                            $self->add_render_attribute('thumbnail', 'src', $atts['thumbnail']['url']);
                            $self->add_render_attribute('thumbnail', 'alt', Control_Media::get_image_alt($atts['thumbnail']));
                            $self->add_render_attribute('thumbnail', 'title', Control_Media::get_image_title($atts['thumbnail']));

                            if (isset($atts['hover_animation_image'])) {
                                $atts['hover_animation'] = $atts['hover_animation_image'];
                            }

                            $output .= '<div class="wgl-image-box_img">';

                            $output .= '<';
                                $output .= implode( ' ', [ $icon_tag,  $link_attributes ] );
                            $output .= '>';
                                $output .= Group_Control_Image_Size::get_attachment_image_html( $atts, 'thumbnail', 'thumbnail' );

                            $output .= '</' . $icon_tag . '>';

                            $output .= '</div>';
                        }

                    $output .= '</div>';
                $output .= '</div>';
            }

            return $output;
        }

        public function template_build()
        {
        }
    }
}
