<?php

namespace WglAddons\Includes;

use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) { exit; }

/**
* Wgl Elementor Helper Settings
*
*
* @class        Wgl_Elementor_Helper
* @version      1.0
* @category Class
* @author       WebGeniusLab
*/

if (!class_exists('Wgl_Elementor_Helper')) {
    class Wgl_Elementor_Helper{

        private static $instance = null;
        public static function get_instance( ) {

            if ( null == self::$instance ) {
                self::$instance = new self( );
            }

            return self::$instance;
        }

        public static function enqueue_css( $style ) {
            if(!(bool) Plugin::$instance->editor->is_edit_mode()){
                if(!empty($style)){
                    ob_start();
                        echo $style;
                    $css = ob_get_clean();
                    $css = apply_filters( 'stoni_enqueue_shortcode_css', $css, $style );

                    return $css;
                }
            }else{
                echo '<style>'.esc_attr($style).'</style>';
            }
        }

        public function get_elementor_templates() {

            $options = array();

            $_templates = get_posts( array(
                'post_type' => 'elementor_library',
                'posts_per_page' => -1,
            ));

            if ( ! empty( $_templates ) && ! is_wp_error( $_templates ) ) {

                foreach ( $_templates as $_template ) {
                    $options[ $_template->ID ] = $_template->post_title;
                }

                update_option( 'temp_count', $options );

                return $options;
            }
        }

        /**
         * Retrieve image dimensions based on passed arguments.
         *
         * @param array|string $desired_dimensions  Required. Desired dimensions. Ex: `700x300`, `[700, 300]`, `['width' => 700, 'height' => 300]`
         * @param string       $aspect_ratio        Required. Desired ratio. Ex: `16:9`
         * @param array        $img_data            Optional. Result of `wp_get_attachment_image_src` function.
         */
        public static function get_image_dimensions(
            $desired_dimensions,
            String $aspect_ratio,
            Array $img_data = []
        ) {
            if ($aspect_ratio) {
                $ratio_arr = explode(':', $aspect_ratio);
                $ratio = round($ratio_arr[0] / $ratio_arr[1], 4);
            }

            if ('full' === $desired_dimensions) {
                $attachemnt_data = $img_data ?: wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full');

                if (!$attachemnt_data) {
                    // Bailout, if no featured image
                    return;
                }

                return [
                    'width' => $attachemnt_data[1],
                    'height' => isset($ratio) ? round((int) $attachemnt_data[1] / $ratio) : $attachemnt_data[2]
                ];
            }

            if (is_array($desired_dimensions)) {
                $desired_width = $desired_dimensions['width'];
                $desired_height = $desired_dimensions['height'];
            } else {
                $dims = explode('x', $desired_dimensions);
                $desired_width = $dims[0];
                $desired_height = !empty($dims[1]) ? $dims[1] : $dims[0];
            }

            return [
                'width' => (int) $desired_width,
                'height' => isset($ratio) ? round($desired_width / $ratio) : (int) $desired_height
            ];
        }
    }
    new Wgl_Elementor_Helper;
}
?>