<?php
namespace WglAddons\Widgets;

use WglAddons\Includes\Wgl_Loop_Settings;
use WglAddons\Includes\Wgl_Carousel_Settings;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Wgl_Blog extends Widget_Base {

    public function get_name() {
        return 'wgl-blog';
    }

    public function get_title() {
        return esc_html__('Wgl Blog', 'stoni-core' );
    }

    public function get_icon() {
        return 'wgl-blog';
    }

    public function get_script_depends() {
        return [
            'slick',
            'jarallax',
            'jarallax-video',
            'imagesloaded',
            'isotope',
            'wgl-elementor-extensions-widgets',
        ];
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }

    // Adding the controls fields for the premium title
    // This will controls the animation, colors and background, dimensions etc
    protected function register_controls() {
        $theme_color = esc_attr(\Stoni_Theme_Helper::get_option('theme-custom-color'));
        $theme_secondary_color = esc_attr(\Stoni_Theme_Helper::get_option('theme-secondary-color'));
        $main_font_color = esc_attr(\Stoni_Theme_Helper::get_option('main-font')['color']);
        $header_font_color = esc_attr(\Stoni_Theme_Helper::get_option('header-font')['color']);

        /* Start General Settings Section */
        $this->start_controls_section('wgl_blog_section',
            array(
                'label'         => esc_html__('Settings', 'stoni-core'),
            )
        );


        /*Title Text*/
        $this->add_control('blog_title',
            array(
                'label'         => esc_html__('Title', 'stoni-core'),
                'type'          => Controls_Manager::TEXT,
                'label_block'   => true,
                'dynamic'       => [ 'active' => true ]
            )
        );
        $this->add_control('blog_subtitle',
            array(
                'label'         => esc_html__('Sub Title', 'stoni-core'),
                'type'          => Controls_Manager::TEXT,
                'label_block'   => true,
                'dynamic'       => [ 'active' => true ]
            )
        );

        $this->add_control(
            'blog_columns',
            array(
                'label'          => esc_html__( 'Grid Columns Amount', 'stoni-core' ),
                'type'           => Controls_Manager::SELECT,

                'options'        => array(
                    '12' => esc_html__( 'One', 'stoni-core' ),
                    '6'  => esc_html__( 'Two', 'stoni-core' ),
                    '4'  => esc_html__( 'Three', 'stoni-core' ),
                    '3'  =>esc_html__( 'Four', 'stoni-core' )
                ),
                'default'        => '12',
                'tablet_default' => 'inherit',
                'mobile_default' => '1',
                'frontend_available' => true,
                'label_block'  => true,
            )
        );

        $this->add_control('blog_layout',
            array(
                'label'         => esc_html__( 'Layout', 'stoni-core' ),
                'type'          => 'wgl-radio-image',
                'options'       => [
                    'grid'      => [
                        'title'=> esc_html__( 'Grid', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/layout_grid.png',
                    ],
                    'masonry'    => [
                        'title'=> esc_html__( 'Masonry', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/layout_masonry.png',
                    ],
                    'carousel'     => [
                        'title'=> esc_html__( 'Carousel', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/layout_carousel.png',
                    ],
                ],
                'default'       => 'grid',            )
        );

        $this->add_control('blog_navigation',
            array(
                'label'             => esc_html__('Navigation Type', 'stoni-core'),
                'type'              => Controls_Manager::SELECT,
                'options'           => [
                    'none'          => esc_html__('None', 'stoni-core'),
                    'pagination'    => esc_html__('Pagination', 'stoni-core'),
                    'load_more'     => esc_html__('Load More', 'stoni-core'),
                ],
                'default'           => 'none',
                'condition'     => [
                    'blog_layout'   => array('grid', 'masonry')
                ]
            )
        );

        $this->add_control('blog_navigation_align',
            array(
                'label'             => esc_html__('Navigation\'s Alignment', 'stoni-core'),
                'type'              => Controls_Manager::SELECT,
                'options'           => [
                    'left'          => esc_html__('Left', 'stoni-core'),
                    'center'        => esc_html__('Center', 'stoni-core'),
                    'right'         => esc_html__('Right', 'stoni-core'),
                ],
                'default'           => 'left',
                'condition'         => [
                    'blog_navigation'   => 'pagination'
                ]
            )
        );

        $this->add_control('items_load',
            array(
                'label'         => esc_html__('Items to be loaded', 'stoni-core'),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('4','stoni-core'),
                'condition'     => [
                    'blog_navigation'   => 'load_more',
                    'blog_layout'   => array('grid', 'masonry')
                ]
            )
        );

        $this->add_control('name_load_more',
            array(
                'label'         => esc_html__('Button Text', 'stoni-core'),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Load More','stoni-core'),
                'condition'     => [
                    'blog_navigation'   => 'load_more',
                    'blog_layout'   => array('grid', 'masonry')
                ]
            )
        );

        $this->add_control(
            'spacer_load_more',
            array(
                'label' => esc_html__( 'Button Spacer Top', 'stoni-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -20,
                        'max' => 200,
                    ],
                ],
                'size_units' => [ 'px', 'em', 'rem', 'vw' ],
                'condition'     => [
                    'blog_navigation'   => 'load_more',
                    'blog_layout'   => array('grid', 'masonry')
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '20',
                ],
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            )
        );


        /*End General Settings Section*/
        $this->end_controls_section();

        $this->start_controls_section(
            'display_section',
            array(
                'label' => esc_html__('Display', 'stoni-core' ),
            )
        );

        $this->add_control(
            'hide_media',
            array(
                'label'        => esc_html__('Hide Media?','stoni-core' ),

                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_blog_title',
            array(
                'label'        => esc_html__('Hide Title?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_content',
            array(
                'label'        => esc_html__('Hide Content?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_postmeta',
            array(
                'label'        => esc_html__('Hide all post-meta?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'meta_author',
            array(
                'label'        => esc_html__('Hide post-meta author?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'condition'     => [
                    'hide_postmeta!'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'meta_comments',
            array(
                'label'        => esc_html__('Hide post-meta comments?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'condition'     => [
                    'hide_postmeta!'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'meta_categories',
            array(
                'label'        => esc_html__('Hide post-meta categories?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'condition'     => [
                    'hide_postmeta!'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'meta_date',
            array(
                'label'        => esc_html__('Hide post-meta date?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'condition'     => [
                    'hide_postmeta!'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'hide_likes',
            array(
                'label'        => esc_html__('Hide Likes?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'hide_share',
            array(
                'label'        => esc_html__('Hide Post Share?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );

        $this->add_control(
            'read_more_hide',
            array(
                'label'        => esc_html__('Hide \'Read More\' button?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control('read_more_text',
            array(
                'label'         => esc_html__('Read More Text', 'stoni-core'),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Read More','stoni-core'),
                'dynamic'       => [ 'active' => true ],
                'condition'     => [
                    'read_more_hide'   => '',
                ]
            )
        );

        $this->add_control('content_letter_count',
            array(
                'label'       => esc_html__('Characters Amount in Content', 'stoni-core'),
                'type'        => Controls_Manager::NUMBER,
                'default'     => '95',
                'min'         => 1,
                'step'        => 1,
                'condition'     => [
                    'hide_content'   => '',
                ]
            )
        );

        $this->add_control(
            'crop_square_img',
            array(
                'label'        => esc_html__('Crop Images for Posts List?','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'description'  => esc_html__( 'For correctly work uploaded image size should be larger than 700px height and width.', 'text-domain' ),
            )
        );

        $this->end_controls_section();


        /* Start Carousel General Settings Section */
        $this->start_controls_section('wgl_carousel_section',
            array(
                'label'         => esc_html__('Carousel Options', 'stoni-core'),
                'condition'     => [
                    'blog_layout'   => 'carousel',
                ]
            )
        );

        $this->add_control(
            'autoplay',
            array(
                'label'        => esc_html__('Autoplay','stoni-core' ),

                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control('autoplay_speed',
            array(
                'label'       => esc_html__('Autoplay Speed', 'stoni-core'),
                'type'        => Controls_Manager::NUMBER,
                'default'     => '3000',
                'min'         => 1,
                'step'        => 1,
                'condition'     => [
                    'autoplay'  => 'yes',
                ]
            )
        );

        $this->add_control(
            'use_pagination',
            array(
                'label'        => esc_html__('Add Pagination control','stoni-core' ),

                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control('pag_type',
            array(
                'label'         => esc_html__( 'Pagination Type', 'stoni-core' ),
                'type'          => 'wgl-radio-image',
                'options'       => [
                    'circle'      => [
                        'title'=> esc_html__( 'Circle', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/pag_circle.png',
                    ],
                    'circle_border' => [
                        'title'=> esc_html__( 'Empty Circle', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/pag_circle_border.png',
                    ],
                    'square'    => [
                        'title'=> esc_html__( 'Square', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/pag_square.png',
                    ],
                    'line'    => [
                        'title'=> esc_html__( 'Line', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/pag_line.png',
                    ],
                    'line_circle'    => [
                        'title'=> esc_html__( 'Line - Circle', 'stoni-core' ),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_composer_addon/icons/pag_line_circle.png',
                    ],
                ],
                'default'       => 'circle',
                'condition'     => [
                    'use_pagination'  => 'yes',
                ]
            )
        );

        $this->add_control('pag_offset',
            array(
                'label'       => esc_html__('Pagination Top Offset', 'stoni-core'),
                'type'        => Controls_Manager::NUMBER,
                'min'         => 1,
                'step'        => 1,
                'condition'     => [
                    'use_pagination'  => 'yes',
                ]
            )
        );

        $this->add_control(
            'custom_pag_color',
            array(
                'label'        => esc_html__('Custom Pagination Color','stoni-core' ),

                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'pag_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default'      => esc_attr($theme_color),
                'condition'     => [
                    'custom_pag_color'  => 'yes',
                ]
            )
        );

        $this->add_control(
            'use_navigation',
            array(
                'label'        => esc_html__('Add Navigation control','stoni-core' ),

                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            )
        );


        $this->add_control('custom_resp',
            array(
                'label'        => esc_html__('Customize Responsive','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'heading_desktop',
            array(
                'label' => esc_html__( 'Desktop Settings', 'stoni-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'after',
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_medium',
            array(
                'label'             => esc_html__('Desktop Screen Breakpoint', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'default'           => '1025',
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_medium_slides',
            array(
                'label'             => esc_html__('Slides to show', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'heading_tablet',
            array(
                'label' => esc_html__( 'Tablet Settings', 'stoni-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'after',
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_tablets',
            array(
                'label'             => esc_html__('Tablet Screen Breakpoint', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'default'           => '800',
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_tablets_slides',
            array(
                'label'             => esc_html__('Slides to show', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control(
            'heading_mobile',
            array(
                'label' => esc_html__( 'Mobile Settings', 'stoni-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'after',
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_mobile',
            array(
                'label'             => esc_html__('Mobile Screen Breakpoint', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'default'           => '480',
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        $this->add_control('resp_mobile_slides',
            array(
                'label'             => esc_html__('Slides to show', 'stoni-core'),
                'type'              => Controls_Manager::NUMBER,
                'min'               => 1,
                'step'              => 1,
                'condition'         => [
                    'custom_resp'   => 'yes',
                ]
            )
        );

        /*End General Settings Section*/
        $this->end_controls_section();



        /*-----------------------------------------------------------------------------------*/
        /*  Build Query Section
        /*-----------------------------------------------------------------------------------*/

        Wgl_Loop_Settings::init( $this, array( 'post_type' => 'post') );

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section(Headings Section)
        /*-----------------------------------------------------------------------------------*/
        $this->start_controls_section(
            'headings_style_section',
            array(
                'label'     => esc_html__( 'Headings', 'stoni-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_control('heading_tag',
            array(
                'label'         => esc_html__('Heading tag', 'stoni-core'),
                'type'          => Controls_Manager::SELECT,
                'default'       => 'h3',
                'options'       => [
                    'h1'    => 'H1',
                    'h2'    => 'H2',
                    'h3'    => 'H3',
                    'h4'    => 'H4',
                    'h5'    => 'H5',
                    'h6'    => 'H6',
                ],
            )
        );

        $this->add_responsive_control(
            'heading_margin',
            array(
                'label' => esc_html__( 'Heading margin', 'stoni-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default'   => [
                    'top'       => 0,
                    'left'      => 0,
                    'right'     => 0,
                    'bottom'    => 11,
                    'unit'      => 'px',
                    'isLinked'  => false
                ],
                'selectors' => [
                    '{{WRAPPER}} .blog-post_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            )
        );


        $this->start_controls_tabs( 'headings_color' );

        $this->start_controls_tab(
            'custom_headings_color_normal',
            array(
                'label' => esc_html__( 'Normal' , 'stoni-core' ),
            )
        );

        $this->add_control(
            'custom_headings_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => esc_attr($header_font_color),
                'selectors' => array(
                    '{{WRAPPER}} .blog-post_title a' => 'color: {{VALUE}};',
                ),
            )
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'custom_headings_color_hover',
            array(
                'label' => esc_html__( 'Hover' , 'stoni-core' ),
            )
        );

        $this->add_control(
            'custom_hover_headings_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => esc_attr($theme_secondary_color),
                'selectors' => array(
                    '{{WRAPPER}} .blog-post_title a:hover' => 'color: {{VALUE}};',
                ),
            )
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'name' => 'custom_fonts_blog_headings',
                'selector' => '{{WRAPPER}} .blog-post_title, {{WRAPPER}} .blog-post_title > a',
            )
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_style_section',
            array(
                'label'     => esc_html__( 'Content', 'stoni-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_responsive_control(
            'content_margin',
            array(
                'label' => esc_html__( 'Margin', 'stoni-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default'   => [
                    'top'       => 0,
                    'left'      => 0,
                    'right'     => 0,
                    'bottom'    => 14,
                    'unit'      => 'px',
                    'isLinked'  => false
                ],
                'selectors' => [
                    '{{WRAPPER}} .blog-style-standard .blog-post_text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            )
        );


        $this->add_control(
            'custom_content_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => esc_attr($main_font_color),
                'selectors' => array(
                    '{{WRAPPER}} .blog-post_text' => 'color: {{VALUE}};',
                ),
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'name' => 'custom_fonts_blog_content',
                'selector' => '{{WRAPPER}} .blog-post_text',
            )
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'meta_info_style_section',
            array(
                'label'     => esc_html__( 'Meta Info', 'stoni-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_responsive_control(
            'meta_info_margin',
            array(
                'label' => esc_html__( 'Margin', 'stoni-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default'   => [
                    'top'       => 0,
                    'left'      => 0,
                    'right'     => 0,
                    'bottom'    => -3,
                    'unit'      => 'px',
                    'isLinked'  => false
                ],
                'selectors' => [
                    '{{WRAPPER}} .blog-style-standard .blog-post .blog-post_content > .meta-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            )
        );

        $this->start_controls_tabs( 'tabs_meta_info' );

        $this->start_controls_tab(
            'tab_meta_info_normal',
            [
                'label' => esc_html__( 'Normal', 'stoni-core' ),
            ]
        );

        $this->add_control(
            'custom_main_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => esc_attr($main_font_color),
                'selectors' => array(
                    '{{WRAPPER}} .meta-wrapper' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .meta-wrapper a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_meta-categories .lavalamp-object' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_meta-categories a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_meta-categories span' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_likes-wrap .sl-count' => 'color: {{VALUE}};',
                ),
            )
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_meta_hover',
            [
                'label' => esc_html__( 'Hover', 'stoni-core' ),
            ]
        );

        $this->add_control(
            'custom_main_color_hover',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => esc_attr($theme_color),
                'selectors' => array(
                    '{{WRAPPER}} .blog-post_meta-categories:hover a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_meta-categories:hover span' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .blog-post_likes-wrap:hover .sl-count' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .meta-wrapper a:hover' => 'color: {{VALUE}};',
                ),
            )
        );


        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'media_style_section',
            array(
                'label'     => esc_html__( 'Media', 'stoni-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_control(
            'custom_blog_mask',
            array(
                'label'        => esc_html__('Add Image Idle Overlay','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );


        $this->add_group_control(
            Group_Control_Background::get_type(),
            array(
                'name' => 'custom_image_mask_color',
                'label' => esc_html__( 'Background', 'stoni-core' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .wrapper',
                'default'  => 'rgba(14,21,30,.6)',
                'condition'     => [
                    'custom_blog_mask'   => 'yes',
                ],
                'selector' => '{{WRAPPER}} .blog-post_bg_media:before,
                {{WRAPPER}} .blog-post.format-standard-image .blog-post_media .blog-post_feature-link:before',
            )
        );

        $this->add_control(
            'custom_blog_hover_mask',
            array(
                'label'        => esc_html__('Add Image Hover Overlay','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );


        $this->add_group_control(
            Group_Control_Background::get_type(),
            array(
                'name' => 'custom_image_hover_mask_color',
                'label' => esc_html__( 'Background', 'stoni-core' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .wrapper',
                'default'  => 'rgba(14,21,30,.6)',
                'condition'     => [
                    'custom_blog_hover_mask'   => 'yes',
                ],
                'selector' => '{{WRAPPER}} .blog-post:hover .blog-post_bg_media:before,
                {{WRAPPER}} .blog-post.hide_media:hover,
                {{WRAPPER}} .blog-post.format-standard-image .blog-post_media:hover .blog-post_feature-link:before',
            )
        );

        $this->add_control(
            'custom_blog_bg_item',
            array(
                'label'        => esc_html__('Add Items Background','stoni-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'stoni-core' ),
                'label_off'    => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
            )
        );


        $this->add_group_control(
            Group_Control_Background::get_type(),
            array(
                'name' => 'custom_bg_color',
                'label' => esc_html__( 'Background', 'stoni-core' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .wrapper',
                'default'  => 'rgba(19,17,31,1)',
                'condition'     => [
                    'custom_blog_bg_item'   => 'yes',
                ],
                'selector' => '{{WRAPPER}} .blog-post,
                {{WRAPPER}} .blog-post .blog-post_media .meta-wrapper',
            )
        );

        $this->end_controls_section();

    }

    public function cache_query($args = array()){

        $args['update_post_term_cache'] = false; // don't retrieve post terms
        $args['update_post_meta_cache'] = false; // don't retrieve post meta
        $k = http_build_query( $args );
        $custom_query = wp_cache_get( $k, 'stoni_theme' );
        if ( false ===  ($custom_query) ) {
            $custom_query = new \WP_Query( $args );
            if ( ! is_wp_error( $custom_query ) && $custom_query->have_posts() ) {
                wp_cache_set( $k, $custom_query, 'stoni_theme' );
            }
        }

        return $custom_query;
    }

    protected function render() {
        $atts = $this->get_settings_for_display();

        extract($atts);

        list($query_args) = Wgl_Loop_Settings::buildQuery($atts);

        // Add Page to Query
        global $paged;
        if (empty($paged)) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        }
        $query_args['paged'] = $paged;

        //Add Optimized SQL
        if ( $blog_navigation == 'none' ) {
            $query_args['no_found_rows'] = true;
        }

        $query = $this->cache_query($query_args);

        // Render Items blog
        $wgl_def_atts = array(
            'query' => $query,
            // General
            'blog_layout' => '',
            'blog_title' => '',
            'blog_subtitle' => '',
            // Content
            'blog_columns' => '',
            'hide_media' => '',
            'hide_share' => $hide_share,
            'hide_content' => '',
            'hide_blog_title' => '',
            'hide_postmeta' => '',
            'meta_author' => '',
            'meta_comments' => '',
            'meta_categories' => '',
            'meta_date' => '',
            'hide_likes' => $hide_likes,
            'read_more_hide' => $read_more_hide,
            'read_more_text' => '',
            'content_letter_count' => '',
            'crop_square_img' => $crop_square_img,
            'heading_tag' => '',
            'items_load'  => $items_load,
            'name_load_more' => $name_load_more
        );

        global $wgl_blog_atts;
        $wgl_blog_atts = array_merge($wgl_def_atts, array_intersect_key($atts, $wgl_def_atts));
        ob_start();

        get_template_part('templates/post/post', 'standard');

        $blog_items = ob_get_clean();

        // Render row class
        $row_class = '';

        wp_enqueue_script( 'imagesloaded' );
        if ($blog_layout == 'masonry') {
            // Call Wordpress Isotope
            wp_enqueue_script( 'isotope', WGL_ELEMENTOR_ADDONS_URL . 'assets/js/isotope.pkgd.min.js' );
            $row_class .= 'blog_masonry';
        }

        // Allowed HTML render
        $allowed_html = array(
            'a' => array(
                'href' => true,
                'title' => true,
            ),
            'br' => array(),
            'em' => array(),
            'strong' => array()
        );

        // Options for carousel
        if ($blog_layout == 'carousel') {
            switch ($blog_columns){
                case '6':  $item_grid = 2; break;
                case '3':  $item_grid = 4; break;
                case '4':  $item_grid = 3; break;
                case '12': $item_grid = 1; break;
                default:   $item_grid = 6; break;
            }

            $carousel_options_arr = array(
                'slide_to_show' => $item_grid,
                'autoplay' => $autoplay,
                'autoplay_speed' => $autoplay_speed,
                'use_pagination' => $use_pagination,
                'use_navigation' => $use_navigation,
                'pag_type' => $pag_type,
                'pag_offset' => $pag_offset,
                'custom_pag_color' => $custom_pag_color,
                'pag_color' => $pag_color,
                'custom_resp' => $custom_resp,
                'resp_medium' => $resp_medium,
                'resp_medium_slides' => $resp_medium_slides,
                'resp_tablets' => $resp_tablets,
                'resp_tablets_slides' => $resp_tablets_slides,
                'resp_mobile' => $resp_mobile,
                'resp_mobile_slides' => $resp_mobile_slides,
                'adaptive_height'   => true
            );

            if ((bool)$use_navigation) {
                $carousel_options_arr['use_prev_next'] = 'true';
            }

            wp_enqueue_script('slick', get_template_directory_uri() . '/js/slick.min.js', array(), false, false);

            $blog_items = Wgl_Carousel_Settings::init($carousel_options_arr, $blog_items, false);

            $row_class = 'blog_carousel';
            if(!empty($blog_title) || !empty($blog_title)){
                $row_class .= ' blog_carousel_title-arrow';
            }
        }

        // Row class for grid and massonry
        if ( in_array($blog_layout, array('grid', 'masonry')) ) {

            switch ( $blog_columns ) {
                case '12': $row_class .= ' blog_columns-1'; break;
                case '6':  $row_class .= ' blog_columns-2'; break;
                case '4':  $row_class .= ' blog_columns-3'; break;
                case '3':  $row_class .= ' blog_columns-4'; break;
            }
            $row_class .= ' '.$blog_layout;
        }
        $row_class .= " blog-style-standard";
        // Render wraper
        if ($query->have_posts()): ?>
            <section class="wgl_cpt_section">
                <div class="blog-posts">
                    <?php
                    if(!empty($blog_title) || !empty($blog_subtitle)){
                        echo '<div class="wgl_module_title item_title">';
                        if (!empty($blog_title)) echo '<h3 class="stoni_module_title blog_title">'.wp_kses( $blog_title, $allowed_html ).'</h3>';
                        if (!empty($blog_subtitle)) echo '<p class="blog_subtitle">'.wp_kses( $blog_subtitle, $allowed_html ).'</p>';

                        if ($blog_layout == 'carousel' && (bool) $use_navigation) {
                            echo '<div class="carousel_arrows"><span class="left_slick_arrow"><span></span></span><span class="right_slick_arrow"><span></span></span></div>';
                        }
                        echo '</div>';
                    }
                    echo '<div class="container-grid row '. esc_attr($row_class) .'">';
                        echo \Stoni_Theme_Helper::render_html($blog_items);
                    echo '</div>';
                    ?>
                </div>
        <?php

        if ( $blog_navigation == 'pagination' ) {
            echo \Stoni_Theme_Helper::pagination('10', $query, $blog_navigation_align);
        }

        if ( $blog_navigation == 'load_more' ) {
            $wgl_blog_atts['post_count'] = $query->post_count;
            $wgl_blog_atts['query_args'] = $query_args;
            $wgl_blog_atts['atts'] = $atts;
            $class  = 'blog_load_more';
            echo \Stoni_Theme_Helper::load_more($wgl_blog_atts, $name_load_more, $class);
        }
            echo '</section>';
        endif;

        // Clear global var
        unset($wgl_blog_atts);

    }

    public function wpml_support_module() {
        add_filter( 'wpml_elementor_widgets_to_translate',  [$this, 'wpml_widgets_to_translate_filter']);
    }

    public function wpml_widgets_to_translate_filter( $widgets ){
        return \WglAddons\Includes\Wgl_WPML_Settings::get_translate(
            $this, $widgets
        );
    }

}