<?php

namespace WglAddons\Widgets;

defined('ABSPATH') || exit; // Abort, if called directly.

use Elementor\{
    Widget_Base,
    Controls_Manager,
    Group_Control_Typography
};
use WglAddons\Templates\WglCountDown;

class Wgl_CountDown extends Widget_Base
{
    public function get_name()
    {
        return 'wgl-countdown';
    }

    public function get_title()
    {
        return esc_html__('Wgl Countdown Timer', 'stoni-core');
    }

    public function get_icon()
    {
        return 'wgl-countdown';
    }

    public function get_categories()
    {
        return ['wgl-extensions'];
    }

    public function get_script_depends()
    {
        return [
            'jquery-coundown',
            'wgl-elementor-extensions-widgets',
        ];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'wgl_countdown_section',
            array(
                'label' => esc_html__('Countdown Timer Settings', 'stoni-core'),
            )
        );

        $this->add_control(
            'countdown_year',
            array(
                'label' => esc_html__('Year', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Enter your title', 'stoni-core'),
                'default' => esc_html__('2020', 'stoni-core'),
                'label_block' => true,
                'description' => esc_html__('Example: 2020', 'stoni-core'),
            )
        );

        $this->add_control(
            'countdown_month',
            array(
                'label' => esc_html__('Month', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('12', 'stoni-core'),
                'default' => esc_html__('12', 'stoni-core'),
                'label_block' => true,
                'description' => esc_html__('Example: 12', 'stoni-core'),
            )
        );

        $this->add_control(
            'countdown_day',
            array(
                'label' => esc_html__('Day', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('31', 'stoni-core'),
                'default' => esc_html__('31', 'stoni-core'),
                'label_block' => true,
                'description' => esc_html__('Example: 31', 'stoni-core'),
            )
        );

        $this->add_control(
            'countdown_hours',
            array(
                'label' => esc_html__('Hours', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('24', 'stoni-core'),
                'default' => esc_html__('24', 'stoni-core'),
                'label_block' => true,
                'description' => esc_html__('Example: 24', 'stoni-core'),
            )
        );

        $this->add_control(
            'countdown_min',
            array(
                'label' => esc_html__('Minutes', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('59', 'stoni-core'),
                'default' => esc_html__('59', 'stoni-core'),
                'label_block' => true,
                'description' => esc_html__('Example: 59', 'stoni-core'),
            )
        );

        $this->end_controls_section();

        /*-----------------------------------------------------------------------------------*/
        /*  Button Section
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'wgl_countdown_content_section',
            array(
                'label' => esc_html__('Countdown Timer Content', 'stoni-core'),
            )
        );

        $this->add_control(
            'hide_day',
            array(
                'label' => esc_html__('Hide Days?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_hours',
            array(
                'label' => esc_html__('Hide Hours?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_minutes',
            array(
                'label' => esc_html__('Hide Minutes?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'hide_seconds',
            array(
                'label' => esc_html__('Hide Seconds?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
            )
        );

        $this->add_control(
            'show_value_names',
            array(
                'label' => esc_html__('Show Value Names?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            )
        );

        $this->add_control(
            'show_separating',
            array(
                'label' => esc_html__('Show Separating?', 'stoni-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'stoni-core'),
                'label_off' => esc_html__('Off', 'stoni-core'),
                'return_value' => 'yes',
            )
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'countdown_style_section',
            array(
                'label' => esc_html__('Style', 'stoni-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_control(
            'size',
            array(
                'label' => esc_html__('Countdown Size', 'stoni-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'large' => esc_html__('Large', 'stoni-core'),
                    'medium' => esc_html__('Medium', 'stoni-core'),
                    'small' => esc_html__('Small', 'stoni-core'),
                    'custom' => esc_html__('Custom', 'stoni-core'),
                ],
                'default' => 'small'
            )
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'label' => esc_html__('Number Typography', 'stoni-core'),
                'name' => 'custom_fonts_number',
                'selector' => '{{WRAPPER}} .wgl-countdown .countdown-section .countdown-amount',
                'condition' => [
                    'size' => 'custom'
                ]
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'label' => esc_html__('Text Typography', 'stoni-core'),
                'name' => 'custom_fonts_text',
                'selector' => '{{WRAPPER}} .wgl-countdown .countdown-section .countdown-period',
                'condition' => [
                    'size' => 'custom'
                ]
            )
        );

        $this->add_control(
            'number_text_color',
            array(
                'label' => esc_html__('Number Color', 'stoni-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#323232',
                'selectors' => [
                    '{{WRAPPER}} .wgl-countdown .countdown-section .countdown-amount' => 'color: {{VALUE}};',
                ],
            )
        );

        $this->add_control(
            'number_text_bg_color',
            array(
                'label' => esc_html__('Number Background Color', 'stoni-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .wgl-countdown .countdown-section .countdown-amount' => 'background-color: {{VALUE}};',
                ],
            )
        );

        $this->add_control(
            'period_text_color',
            array(
                'label' => esc_html__('Text Color', 'stoni-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .wgl-countdown .countdown-section .countdown-period' => 'color: {{VALUE}};',
                ],
            )
        );

        $this->add_control(
            'separating_color',
            array(
                'label' => esc_html__('Separating Points Color', 'stoni-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .wgl-countdown .countdown-section:not(:last-child) .countdown-amount:before' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .wgl-countdown .countdown-section:not(:last-child) .countdown-amount:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'show_separating' => 'yes'
                ]
            )
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $atts = $this->get_settings_for_display();

        $countdown = new WglCountDown();
        echo $countdown->render($this, $atts);
    }

    public function wpml_support_module() {
        add_filter( 'wpml_elementor_widgets_to_translate',  [$this, 'wpml_widgets_to_translate_filter']);
    }

    public function wpml_widgets_to_translate_filter( $widgets ){
        return \WglAddons\Includes\Wgl_WPML_Settings::get_translate(
            $this, $widgets
        );
    }
}
