<?php

namespace WglAddons\Widgets;

defined('ABSPATH') || exit;

use Elementor\{
    Widget_Base,
    Controls_Manager,
    Control_Media,
    Core\Schemes\Typography,
    Group_Control_Typography,
    Repeater
};

class Wgl_Time_Line_Vertical extends Widget_Base
{
    public function get_name()
    {
        return 'wgl-time-line-vertical';
    }

    public function get_title()
    {
        return esc_html__('Wgl Time Line Vertical', 'stoni-core');
    }

    public function get_icon()
    {
        return 'wgl-time-line-vertical';
    }

    public function get_categories()
    {
        return ['wgl-extensions'];
    }

    public function get_script_depends()
    {
        return ['jquery-appear'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'wgl_time_line_section',
            array(
                'label' => esc_html__('General Settings', 'stoni-core'),
            )
        );

        $this->add_control(
            'add_appear',
            array(
                'label' => esc_html__('Add Appear Animation','stoni-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'On', 'stoni-core' ),
                'label_off' => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            )
        );

        $this->add_control(
            'add_grayscale',
            array(
                'label' => esc_html__('Add Grayscale Animation','stoni-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'On', 'stoni-core' ),
                'label_off' => esc_html__( 'Off', 'stoni-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'content',
            array(
                'label' => esc_html__('Content', 'stoni-core'),
                'type' => Controls_Manager::WYSIWYG,
                'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Optio, neque qui velit. Magni dolorum quidem ipsam eligendi, totam, facilis laudantium cum accusamus ullam voluptatibus commodi numquam, error, est. Ea, consequatur.', 'stoni-core'),
                'dynamic' => ['active' => true],
            )
        );

        $repeater->add_control(
            'date',
            array(
                'label' => esc_html__('Date', 'stoni-core'),
                'type' => Controls_Manager::TEXT,
				'default' => '',
            )
        );

        $repeater->add_control(
            'thumbnail',
            array(
                'label' => esc_html__( 'Thumbnail', 'stoni-core' ),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
                'default' => [
                    'url' => '',
                ],
            )
        );

        $repeater->add_control(
            'content_margin',
            array(
                'label' => esc_html__( 'Content Margin', 'stoni-core' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 0,
                    'right' => 0,
                    'bottom' => 0,
                    'left' => 0,
                    'unit' => 'px',
                    'isLinked' => false,
                ],
            )
        );

        $this->add_control(
            'items',
            array(
                'label' => esc_html__( 'Layers', 'stoni-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            )
        );

        $this->end_controls_section();

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'content_style_section',
            array(
                'label' => esc_html__( 'Content', 'stoni-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typo',
                'selector' => '{{WRAPPER}} .time_line-text'
            ]
        );

        $this->add_control(
            'content_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => array(
                    '{{WRAPPER}} .time_line-text' => 'color: {{VALUE}};',
                ),
            )
        );

        $this->add_control(
            'content_bg_color',
            array(
                'label' => esc_html__( 'Background Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#b49c78',
                'selectors' => array(
                    '{{WRAPPER}} .time_line-text' => 'background-color: {{VALUE}};',
                ),
            )
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'date_style_section',
            array(
                'label' => esc_html__( 'Date', 'stoni-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'name' => 'date_typo',
                'fields_options' => [
                    'typography' => ['default' => 'yes'],
                    'font_family' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_family']],
                ],
                'selector' => '{{WRAPPER}} .time_line-date',
            )
        );

        $this->add_control(
            'date_color',
            array(
                'label' => esc_html__( 'Color', 'stoni-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#f4f4f4',
                'selectors' => array(
                    '{{WRAPPER}} .time_line-date' => 'color: {{VALUE}};',
                ),
            )
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        wp_enqueue_script('jquery-appear', get_template_directory_uri() . '/js/jquery.appear.js');

        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 'timeline-vertical', [
			'class' => [
                'wgl-timeline-vertical',
                ((bool)$settings['add_appear'] ? 'appear_anim' : ''),
                ((bool)$settings['add_grayscale'] ? 'grayscale_anim' : ''),
            ],
        ] );

        ?><div <?php echo $this->get_render_attribute_string( 'timeline-vertical' ); ?>><?php

        foreach ( $settings['items'] as $index => $item ) {

            $image = $this->get_repeater_setting_key( 'image', 'items' , $index );
            $this->add_render_attribute( $image, [
                'src' => esc_url($item['thumbnail']['url']),
                'alt' => Control_Media::get_image_alt( $item['thumbnail'] ),
            ] );

            $item_wrap = $this->get_repeater_setting_key( 'item_wrap', 'items' , $index );
            $this->add_render_attribute( $item_wrap, [
                'class' => [
                    'time_line-item',
                    (!empty($item['thumbnail']['url']) ? '' : 'no-image'),
                ],
            ] );

            $item_text = $this->get_repeater_setting_key( 'item_text', 'items' , $index );
            $this->add_render_attribute( $item_text, [
                'class' => 'time_line-text',
                'style' => 'margin: '.$item['content_margin']['top'].$item['content_margin']['unit'].' '.$item['content_margin']['right'].$item['content_margin']['unit'].' '.$item['content_margin']['bottom'].$item['content_margin']['unit'].' '.$item['content_margin']['left'].$item['content_margin']['unit'],
            ] );

            ?>
            <div <?php echo $this->get_render_attribute_string( $item_wrap ); ?>>
                <div class="time_line-pointer"><div class="time_line-point"></div></div>
                <div class="time_line-content"><?php
                    if (!empty($item['thumbnail']['url'])) {
                        ?><div class="time_line-image">
                            <img <?php echo $this->get_render_attribute_string( $image ); ?> />
                        </div><?php
                    }?>
                    <h4 class="time_line-date"><?php echo $item['date'] ?></h4><?php
                    if (!empty($item['content'])) {?>
                        <div <?php echo $this->get_render_attribute_string( $item_text ); ?>><?php echo $item['content'] ?></div><?php
                    }?>
                </div>
            </div><?php

        }

        ?></div><?php

    }

    public function wpml_support_module() {
        add_filter( 'wpml_elementor_widgets_to_translate',  [$this, 'wpml_widgets_to_translate_filter']);
    }

    public function wpml_widgets_to_translate_filter( $widgets ){
        return \WglAddons\Includes\Wgl_WPML_Settings::get_translate(
            $this, $widgets
        );
    }

}