<?php

defined('ABSPATH') || exit;

use WglAddons\Templates\WglPortfolio;

/**
 * Archive Page Template for Portfolio CPT
 *
 * @package stoni-core\includes\post-types
 * @author WebGeniusLab <webgeniuslab@gmail.com>
 * @since 1.0.0
 * @version 1.1.5
 */

// Filter
$show_filter = Stoni_Theme_Helper::get_option('portfolio_list_show_filter');
$list_terms = Stoni_Theme_Helper::get_option('portfolio_list_filter_cats');
if (!empty($term_id)) {
    $show_filter = '';
}
if (!empty($show_filter) && !empty($list_terms)) {
    $term_id = $list_terms;
}

// Taxonomies
$tax_obj = get_queried_object();
$term_id = $tax_obj->term_id ?? '';
if ($term_id) {
    $taxonomies[] = $tax_obj->taxonomy . ': ' . $tax_obj->slug;
    $tax_description = $tax_obj->description;
}

$archive_attrs = [
    'posts_per_row' => Stoni_Theme_Helper::get_option('portfolio_list_columns'),
    'portfolio_layout' => 'masonry',
    'add_animation' => null,
    'navigation' => 'pagination',
    'nav_align' => 'center',
    'click_area' => 'single',
    'show_portfolio_title' => Stoni_Theme_Helper::get_option('portfolio_list_show_title'),
    'show_content' => Stoni_Theme_Helper::get_option('portfolio_list_show_content'),
    'show_meta_categories' => Stoni_Theme_Helper::get_option('portfolio_list_show_cat'),
    'show_filter' => $show_filter,
    'crop_images' => 'yes',
    'items_load' => '4',
    'grid_gap' => '30px',
    'add_overlay' => 'true',
    'custom_overlay_color' => 'rgba(34,35,40,.7)',
    'image_anim' => 'simple',
    'single_link_title' => 'yes',
    'add_divider' => true,
    'info_position' => 'inside_image',
    // Query
    'number_of_posts' => '12',
    'order_by' => 'menu_order',
    'order' => 'ASC',
    'taxonomies' => $taxonomies ?? [],
];

// Sidebar parameters
$sb = Stoni_Theme_Helper::render_sidebars('portfolio_list');
$row_class = $sb['row_class'];
$column = $sb['column'];
$container_class = $sb['container_class'];

// Render
get_header();

echo '<div class="wgl-container', apply_filters('stoni_container_class', $container_class), '">';
echo '<div class="row', apply_filters('stoni_row_class', $row_class), '">';

    echo '<div id="main-content" class="wgl_col-', apply_filters('stoni_column_class', $column), '">';

        if ($term_id) {
            echo '<div class="portfolio_archive-cat">',
                '<h4 class="portfolio_archive-cat_title">',
                    get_the_archive_title(),
                '</h4>',
                (!empty($tax_description) ? '<div class="portfolio_archive-cat_descr">' . esc_html($tax_description) . '</div>' : ''),
            '</div>';
        }

        echo (new WglPortfolio())->render($archive_attrs);

    echo '</div>';

    echo (!empty($sb['content']) ) ? $sb['content'] : '';

echo '</div>';
echo '</div>';

get_footer();
